@@ -3,7 +3,7 @@ package Protocol::XMLRPC;
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 1;
 __END__
@@ -61,13 +61,19 @@ A simple server for XML-RPC calls.
 
     http://github.com/vti/protocol-xmlrpc/
 
+=head1 CREDITS
+
+Jan Harders
+
+Knut Arne Bjørndal
+
 =head1 AUTHOR
 
 Viacheslav Tykhanovskyi, C<vti@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2009-2011, Viacheslav Tykhanovskyi.
+Copyright (C) 2009-2012, Viacheslav Tykhanovskyi.
 
 This program is free software, you can redistribute it and/or modify it under
 the same terms as Perl 5.10.
