@@ -59,16 +59,3 @@ Returns serialized Perl5 scalar.
     # $string->to_string is now '<string>foo</string>'
 
 XML-RPC string string representation.
-
-=head1 AUTHOR
-
-Viacheslav Tykhanovskyi, C<vti@cpan.org>.
-
-=head1 COPYRIGHT
-
-Copyright (C) 2009, Viacheslav Tykhanovskyi.
-
-This program is free software, you can redistribute it and/or modify it under
-the same terms as Perl 5.10.
-
-=cut
